[−][src]Enum unicode_types::general_punctuation::GeneralPunctuation
An enum to represent all characters in the GeneralPunctuation block.
Variants
EnQuad\u{2000}: ' '
EmQuad\u{2001}: ' '
EnSpace\u{2002}: ' '
EmSpace\u{2003}: ' '
ThreeDashPerDashEmSpace\u{2004}: ' '
FourDashPerDashEmSpace\u{2005}: ' '
SixDashPerDashEmSpace\u{2006}: ' '
FigureSpace\u{2007}: ' '
PunctuationSpace\u{2008}: ' '
ThinSpace\u{2009}: ' '
HairSpace\u{200a}: ' '
ZeroWidthSpace\u{200b}: ''
ZeroWidthNonDashJoiner\u{200c}: ''
ZeroWidthJoiner\u{200d}: ''
LeftDashToDashRightMark\u{200e}: ''
RightDashToDashLeftMark\u{200f}: ''
Hyphen\u{2010}: '‐'
NonDashBreakingHyphen\u{2011}: '‑'
FigureDash\u{2012}: '‒'
EnDash\u{2013}: '–'
EmDash\u{2014}: '—'
HorizontalBar\u{2015}: '―'
DoubleVerticalLine\u{2016}: '‖'
DoubleLowLine\u{2017}: '‗'
LeftSingleQuotationMark\u{2018}: '‘'
RightSingleQuotationMark\u{2019}: '’'
SingleLowDash9QuotationMark\u{201a}: '‚'
SingleHighDashReversedDash9QuotationMark\u{201b}: '‛'
LeftDoubleQuotationMark\u{201c}: '“'
RightDoubleQuotationMark\u{201d}: '”'
DoubleLowDash9QuotationMark\u{201e}: '„'
DoubleHighDashReversedDash9QuotationMark\u{201f}: '‟'
Dagger\u{2020}: '†'
DoubleDagger\u{2021}: '‡'
Bullet\u{2022}: '•'
TriangularBullet\u{2023}: '‣'
OneDotLeader\u{2024}: '․'
TwoDotLeader\u{2025}: '‥'
HorizontalEllipsis\u{2026}: '…'
HyphenationPoint\u{2027}: '‧'
LineSeparator\u{2028}: ' '
ParagraphSeparator\u{2029}: ' '
LeftDashToDashRightEmbedding\u{202a}: ''
RightDashToDashLeftEmbedding\u{202b}: ''
PopDirectionalFormatting\u{202c}: ''
LeftDashToDashRightOverride\u{202d}: ''
RightDashToDashLeftOverride\u{202e}: ''
NarrowNoDashBreakSpace\u{202f}: ' '
PerMilleSign\u{2030}: '‰'
PerTenThousandSign\u{2031}: '‱'
Prime\u{2032}: '′'
DoublePrime\u{2033}: '″'
TriplePrime\u{2034}: '‴'
ReversedPrime\u{2035}: '‵'
ReversedDoublePrime\u{2036}: '‶'
ReversedTriplePrime\u{2037}: '‷'
Caret\u{2038}: '‸'
SingleLeftDashPointingAngleQuotationMark\u{2039}: '‹'
SingleRightDashPointingAngleQuotationMark\u{203a}: '›'
ReferenceMark\u{203b}: '※'
DoubleExclamationMark\u{203c}: '‼'
Interrobang\u{203d}: '‽'
Overline\u{203e}: '‾'
Undertie\u{203f}: '‿'
CharacterTie\u{2040}: '⁀'
CaretInsertionPoint\u{2041}: '⁁'
Asterism\u{2042}: '⁂'
HyphenBullet\u{2043}: '⁃'
FractionSlash\u{2044}: '⁄'
LeftSquareBracketWithQuill\u{2045}: '⁅'
RightSquareBracketWithQuill\u{2046}: '⁆'
DoubleQuestionMark\u{2047}: '⁇'
QuestionExclamationMark\u{2048}: '⁈'
ExclamationQuestionMark\u{2049}: '⁉'
TironianSignEt\u{204a}: '⁊'
ReversedPilcrowSign\u{204b}: '⁋'
BlackLeftwardsBullet\u{204c}: '⁌'
BlackRightwardsBullet\u{204d}: '⁍'
LowAsterisk\u{204e}: '⁎'
ReversedSemicolon\u{204f}: '⁏'
CloseUp\u{2050}: '⁐'
TwoAsterisksAlignedVertically\u{2051}: '⁑'
CommercialMinusSign\u{2052}: '⁒'
SwungDash\u{2053}: '⁓'
InvertedUndertie\u{2054}: '⁔'
FlowerPunctuationMark\u{2055}: '⁕'
ThreeDotPunctuation\u{2056}: '⁖'
QuadruplePrime\u{2057}: '⁗'
FourDotPunctuation\u{2058}: '⁘'
FiveDotPunctuation\u{2059}: '⁙'
TwoDotPunctuation\u{205a}: '⁚'
FourDotMark\u{205b}: '⁛'
DottedCross\u{205c}: '⁜'
Tricolon\u{205d}: '⁝'
VerticalFourDots\u{205e}: '⁞'
MediumMathematicalSpace\u{205f}: ' '
WordJoiner\u{2060}: ''
FunctionApplication\u{2061}: ''
InvisibleTimes\u{2062}: ''
InvisibleSeparator\u{2063}: ''
InvisiblePlus\u{2064}: ''
LeftDashToDashRightIsolate\u{2066}: ''
RightDashToDashLeftIsolate\u{2067}: ''
FirstStrongIsolate\u{2068}: ''
PopDirectionalIsolate\u{2069}: ''
InhibitSymmetricSwapping\u{206a}: ''
ActivateSymmetricSwapping\u{206b}: ''
InhibitArabicFormShaping\u{206c}: ''
ActivateArabicFormShaping\u{206d}: ''
NationalDigitShapes\u{206e}: ''
Methods
impl GeneralPunctuation[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case